%define major 10
%define libname   %mklibname opendkim %{major}
%define develname %mklibname opendkim -d

Name:       opendkim
Version:    2.10.3
Release:    %mkrel 4
Summary:    DomainKeys Identified Mail (DKIM) milter to sign and/or verify mail
Group:      System/Servers
License:    BSD and Sendmail
URL:        http://www.opendkim.org/
Source0:    http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
BuildRequires: sendmail-devel
BuildRequires: db-devel
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libbsd)
BuildRequires: pkgconfig(libmemcached)
BuildRequires: pkgconfig(opendbx)

%description
opendkim allows signing and/or verification of email through an open source
library that implements the DKIM service, plus a milter-based filter
application that can plug in to any milter-aware MTA, including sendmail,
Postfix, or any other MTA that supports the milter protocol.

%package -n %{libname}
Summary: An open source DKIM library
Group: System/Servers

%description -n %{libname}
This package contains the library files required for running services built
using libopendkim.

%package -n %{develname}
Summary: Development files for lib%{name}
Group: Development/Other

%description -n %{develname}
This package contains the static libraries, headers, and other support files
required for developing applications against libopendkim.

%prep
%setup -q

%build
autoreconf -f -i
# Always use system libtool instead of pacakge-provided one to
# properly handle 32 versus 64 bit detection and settings
#define LIBTOOL LIBTOOL=`which libtool`

%configure2_5x --with-libmemcached --with-db --with-odbx

# Remove rpath
%{__sed} -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
%{__sed} -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make

%install
%makeinstall_std
install -d %{buildroot}%{_sysconfdir}
install -d %{buildroot}%{_sysconfdir}/sysconfig
install -m 0755 contrib/init/redhat/%{name}-default-keygen %{buildroot}%{_sbindir}/%{name}-default-keygen

install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 contrib/systemd/%{name}.service %{buildroot}%{_unitdir}/%{name}.service

cat > %{buildroot}%{_sysconfdir}/%{name}.conf << 'EOF'
## BASIC %{bigname} CONFIGURATION FILE
## See %{name}.conf(5) or %{_defaultdocdir}/%{name}/%{name}.conf.sample for more

## BEFORE running opendkim you must:

## - make your MTA (Postfix, Sendmail, etc.) aware of opendkim
## - generate keys for your domain (if signing)
## - edit your DNS records to publish your public keys (if signing)

## See %{_defaultdocdir}/%{name}/INSTALL for detailed instructions.

## CONFIGURATION OPTIONS

##  Specifies the path to the process ID file.
PidFile	%{_localstatedir}/run/%{name}/%{name}.pid

##  Selects operating modes. Valid modes are s (sign) and v (verify). Default
## is v. Must be changed to s (sign only) or sv (sign and verify) in order to
## sign outgoing messages.
Mode	v

##  Log activity to the system log.
Syslog	yes

##  Log additional entries indicating successful signing or verification of
## messages.
SyslogSuccess	yes

##  If logging is enabled, include detailed logging about why or why not a message was
##  signed or verified. This causes an increase in the amount of log data generated
##  for each message, so set this to No (or comment it out) if it gets too noisy.
LogWhy	yes

##  Attempt to become the specified user before starting operations.
UserID	%{name}:%{name}

##  Create a socket through which your MTA can communicate.
Socket	inet:8891@localhost

##  Required to use local socket with MTAs that access the socket as a non-
##  privileged user (e.g. Postfix)
Umask	002

##  This specifies a text file in which to store DKIM transaction statistics.
##  opendkim must be manually compiled with --enable-stats to enable this feature.
# Statistics	%{_localstatedir}/spool/%{name}/stats.dat

##  Specifies whether or not the filter should generate report mail back
##  to senders when verification fails and an address for such a purpose
##  is provided. See opendkim.conf(5) for details.
SendReports	yes

##  Specifies the sending address to be used on From: headers of outgoing
##  failure reports.  By default, the e-mail address of the user executing
##  the filter is used (executing_user@hostname).
# ReportAddress	"Example.com Postmaster" <postmaster@example.com>

##  Add a DKIM-Filter header field to messages passing through this filter
##  to identify messages it has processed.
SoftwareHeader	yes

## SIGNING OPTIONS

##  Selects the canonicalization method(s) to be used when signing messages.
Canonicalization	relaxed/relaxed

##  Domain(s) whose mail should be signed by this filter. Mail from other domains will
##  be verified rather than being signed. Uncomment and use your domain name.
##  This parameter is not required if a SigningTable is in use.
# Domain	example.com

##  Defines the name of the selector to be used when signing messages.
Selector	default

##  Specifies the minimum number of key bits for acceptable keys and signatures.
MinimumKeyBits	1024

##  Gives the location of a private key to be used for signing ALL messages. This
##  directive is ignored if KeyTable is enabled.
KeyFile	%{_sysconfdir}/%{name}/keys/default.private

##  Gives the location of a file mapping key names to signing keys. In simple terms,
##  this tells opendkim where to find your keys. If present, overrides any KeyFile
##  directive in the configuration file. Requires SigningTable be enabled.
# KeyTable	%{_sysconfdir}/%{name}/KeyTable

##  Defines a table used to select one or more signatures to apply to a message based
##  on the address found in the From: header field. In simple terms, this tells
##  opendkim how to use your keys. Requires KeyTable be enabled.
# SigningTable	refile:%{_sysconfdir}/%{name}/SigningTable

##  Identifies a set of "external" hosts that may send mail through the server as one
##  of the signing domains without credentials as such.
# ExternalIgnoreList	refile:%{_sysconfdir}/%{name}/TrustedHosts

##  Identifies a set "internal" hosts whose mail should be signed rather than verified.
# InternalHosts	refile:%{_sysconfdir}/%{name}/TrustedHosts

##  Contains a list of IP addresses, CIDR blocks, hostnames or domain names
##  whose mail should be neither signed nor verified by this filter.  See man
##  page for file format.
# PeerList	X.X.X.X

##  Always oversign From (sign using actual From and a null From to prevent
##  malicious signatures header fields (From and/or others) between the signer
##  and the verifier.  From is oversigned by default in the Fedora package
##  because it is often the identity key used by reputation systems and thus
##  somewhat security sensitive.
OversignHeaders	From
EOF

%{__cat} > %{buildroot}%{_sysconfdir}/sysconfig/%{name} << 'EOF'
# Set the necessary startup options
OPTIONS="-x %{_sysconfdir}/%{name}.conf -P %{_localstatedir}/run/%{name}/%{name}.pid"

# Set the default DKIM selector
DKIM_SELECTOR=default

# Set the default DKIM key location
DKIM_KEYDIR=%{_sysconfdir}/%{name}/keys
EOF

install -d %{buildroot}%{_sysconfdir}/%{name}
cat > %{buildroot}%{_sysconfdir}/%{name}/SigningTable << 'EOF'
# OpenDKIM SIGNING TABLE
# This table controls how to apply one or more signatures to outgoing messages based
# on the address found in the From: header field. In simple terms, this tells
# opendkim "how" to apply your keys.

# To use this file, uncomment the SigningTable option in %{_sysconfdir}/%{name}.conf,
# then uncomment one of the usage examples below and replace example.com with your
# domain name, then restart opendkim.

# WILDCARD EXAMPLE
# Enables signing for any address on the listed domain(s), but will work only if
# "refile:%{_sysconfdir}/%{name}/SigningTable" is included in %{_sysconfdir}/%{name}.conf.
# Create additional lines for additional domains.

#*@example.com default._domainkey.example.com

# NON-WILDCARD EXAMPLE
# If "file:" (instead of "refile:") is specified in %{_sysconfdir}/%{name}.conf, then
# wildcards will not work. Instead, full user@host is checked first, then simply host,
# then user@.domain (with all superdomains checked in sequence, so "foo.example.com"
# would first check "user@foo.example.com", then "user@.example.com", then "user@.com"),
# then .domain, then user@*, and finally *. See the %{name}.conf(5) man page under
# "SigningTable" for more details.

#example.com default._domainkey.example.com
EOF

%{__cat} > %{buildroot}%{_sysconfdir}/%{name}/KeyTable << 'EOF'
# %{bigname} KEY TABLE
# To use this file, uncomment the #KeyTable option in %{_sysconfdir}/%{name}.conf,
# then uncomment the following line and replace example.com with your domain
# name, then restart opendkim. Additional keys may be added on separate lines.

#default._domainkey.example.com example.com:default:%{_sysconfdir}/%{name}/keys/default.private
EOF

cat > %{buildroot}%{_sysconfdir}/%{name}/TrustedHosts << 'EOF'
# %{bigname} TRUSTED HOSTS
# To use this file, uncomment the #ExternalIgnoreList and/or the #InternalHosts
# option in %{_sysconfdir}/%{name}.conf then restart opendkim. Additional hosts
# may be added on separate lines (IP addresses, hostnames, or CIDR ranges).
# The localhost IP (127.0.0.1) should always be the first entry in this file.
127.0.0.1
::1
#host.example.com
#192.168.1.0/24
EOF

cat > README.urpmi << 'EOF'
Generating keys for opendkim
============================
After installing the opendkim package, you MUST generate a pair of keys (public
and private) before attempting to start the opendkim service.

A valid private key must exist in the location expected by %{_sysconfdir}/%{name}.conf before the service will start.

A matching public key must be included in your domain's DNS records before
remote systems can validate your outgoing mail's DKIM signature.

Generating Keys Automatically
=============================
To automatically create a pair of default keys for the local domain, do:

% sudo %{_sbindir}/%{name}-default-keygen

The default keygen script will attempt to fetch the local domain name, generate
a private and public key for the domain, then save them in
%{_sysconfdir}/%{name}/keys as default.private and default.txt with the proper
ownership and permissions.

NOTE: The default key generation script MUST be run by a privileged user (or
root). Otherwise, the resulting private key ownership and permissions will not
be correct.

Generating Keys Manually
========================
A privileged user (or root) can manually generate a set of keys by doing the following:

1) Create a directory to store the new keys:

% sudo mkdir %{_sysconfdir}/%{name}/keys/example.com

2) Generate keys in that directory for a specific domain name and selector:

% sudo %{_sbindir}/%{name}-genkey -D %{_sysconfdir}/%{name}/keys/example.com/ -d example.com -s default

3) Set the proper ownership for the directory and private key:

% sudo chown -R root:%{name} %{_sysconfdir}/%{name}/keys/example.com

4) Set secure permissions for the private key:

% sudo chmod 640 %{_sysconfdir}/%{name}/keys/example.com/default.private

5) Set standard permissions for the public key:

% sudo chmod 644 %{_sysconfdir}/%{name}/keys/example.com/default.txt


Updating Key Location(s) in Configuration Files
===============================================
If you run the %{name}-default-keygen script, the default keys will be saved in %{_sysconfdir}/%{name}/keys as
default.private and default.txt, which is the location expected by the default %{_sysconfdir}/%{name}.conf file.

If you manually generate your own keys, you must update the key location and name in %{_sysconfdir}/%{name}.conf
before attempting to start the %{name} service.


Using opendkim with SQL Datasets
================================
opendkim on Mageia relies on OpenDBX for database access. Depending on which
database you use, you may have to manually install one of the following OpenDBX
subpackages:

- opendbx-firebird
- opendbx-mssql
- opendbx-mysql
- opendbx-postgresql
- opendbx-sqlite 
- opendbx-sqlite2
- opendbx-sybase

If you have opendkim configured to use SQL datasets on a systemd-based server,
it might also be necessary to start the opendkim service after the database
servers by referencing your database unit file(s) in the "After" section of the
opendkim unit file.

For example, if using both MariaDB and PostgreSQL, in %{_unitdir}/%{name}.service change:

After=network.target nss-lookup.target syslog.target

to:

After=network.target nss-lookup.target syslog.target mariadb.service postgresql.service


Additional Configuration Help
=============================
For help configuring your MTA (Postfix, Sendmail, etc.) with opendkim, setting
up DNS records with your public DKIM key, as well as instructions on
configuring opendkim to sign outgoing mail for multiple domains, follow the
how-to at:

http://wp.me/p1iGgP-ou

Official documentation for opendkim is available at http://opendkim.org/

opendkim mailing lists are available at http://lists.opendkim.org/

###
EOF

install -p -d %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<'EOF'
D %{_localstatedir}/run/%{name} 0700 %{name} %{name} -
EOF

rm -rf %{buildroot}%{_prefix}/share/doc/%{name}
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/*.la

install -d %{buildroot}%{_localstatedir}/spool/%{name}
install -d %{buildroot}%{_localstatedir}/run/%{name}
install -d %{buildroot}%{_sysconfdir}/%{name}
install -d -m 750 %{buildroot}%{_sysconfdir}/%{name}/keys

install -m 755 stats/%{name}-reportstats %{buildroot}%{_prefix}/sbin/%{name}-reportstats
sed -i \
    -e 's|^OPENDKIMSTATSDIR="/var/db/%{name}"|OPENDKIMSTATSDIR="%{_localstatedir}/spool/%{name}"|g' \
    -e 's|^OPENDKIMDATOWNER="mailnull:mailnull"|OPENDKIMDATOWNER="%{name}:%{name}"|g' \
     %{buildroot}%{_prefix}/sbin/%{name}-reportstats

chmod 0644 contrib/convert/convert_keylist.sh

%pre
%_pre_useradd opendkim %{_localstatedir}/run/opendkim /sbin/false

%post
%_post_service %{name}.service
%_tmpfilescreate %{name}

%preun
%_preun_service %{name}.service

%files
%doc LICENSE LICENSE.Sendmail
%doc FEATURES KNOWNBUGS RELEASE_NOTES RELEASE_NOTES.Sendmail INSTALL
%doc contrib/convert/convert_keylist.sh %{name}/*.sample
%doc %{name}/%{name}.conf.simple-verify %{name}/%{name}.conf.simple
%doc %{name}/README contrib/lua/*.lua
%doc README.urpmi
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_tmpfilesdir}/%{name}.conf
%config(noreplace) %attr(0640,opendkim,opendkim) %{_sysconfdir}/%{name}/SigningTable
%config(noreplace) %attr(0640,opendkim,opendkim) %{_sysconfdir}/%{name}/KeyTable
%config(noreplace) %attr(0640,opendkim,opendkim) %{_sysconfdir}/%{name}/TrustedHosts
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sbindir}/*
%{_mandir}/*/*
%dir %attr(-,opendkim,opendkim) %{_localstatedir}/spool/%{name}
%dir %attr(-,root,opendkim) %{_sysconfdir}/%{name}
%dir %attr(-,opendkim,opendkim) %{_sysconfdir}/%{name}/keys
%{_sbindir}/%{name}-default-keygen
%{_unitdir}/%{name}.service

%files -n %{libname}
%doc LICENSE LICENSE.Sendmail
%doc README
%{_libdir}/lib%{name}.so.*

%files -n %{develname}
%doc LICENSE LICENSE.Sendmail
%doc lib%{name}/docs/*.html
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Thu Mar 03 2016 umeabot <umeabot> 2.10.3-4.mga6
+ Revision: 983851
- Rebuild for openssl

* Fri Feb 26 2016 luigiwalser <luigiwalser> 2.10.3-3.mga6
+ Revision: 979745
- rebuild with configure2_5x

* Sun Dec 13 2015 guillomovitch <guillomovitch> 2.10.3-2.mga6
+ Revision: 910233
- bump release
- imported package opendkim

